# yaqc-python

[![PyPI](https://img.shields.io/pypi/v/yaqc)](https://pypi.org/project/yaqc)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqc)](https://anaconda.org/conda-forge/yaqc)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://github.com/yaq-project/yaq-python/blob/main/yaqc/CHANGELOG.md)

Generic yaq client, written in Python.
